import java.io.FileInputStream;
import java.io.InputStreamReader;

import java.io.FileReader;
import java.io.BufferedReader;

import java.io.FileWriter;
import java.io.BufferedWriter;
import java.io.PrintWriter;

import java.io.FileNotFoundException;
import java.io.IOException;

import java.nio.charset.Charset;

/**
 * Demo for reading from a text file with a specified encoding 
 * 
 * @author Tomáš Pitner
 * @version Dec 10, 2014
 */
public class BufferedReaderDemo
{
    public static void main(String[] args) throws FileNotFoundException, IOException
    {
        
        BufferedReader br = null;
        PrintWriter pw = null;
        
        try {
            
            InputStreamReader isr = new InputStreamReader(new FileInputStream("pokus.txt"), 
                Charset.forName("UTF-8"));
                
            br = new BufferedReader(isr);
            
            pw = new PrintWriter("pokus-out.txt", "UTF-8");
            
            String line = br.readLine();
            
            while(line != null) {
                pw.println(line);
                line = br.readLine();
            }
            
        } finally {
            if(br != null) {
                br.close();
            }
            if(pw != null) {
                pw.close();
            }
        }
    }
    
    /** 
     * The following method does the same using
     * try with resources constructs introduced in Java 7.
     * It makes the code shorted, and prevents errors
     * (one does not forget to carefully close the streams
     * under all circumstances.
     */
    public static void demoTryWithResources() throws FileNotFoundException, IOException
    {
        // Here we can also use multiple try-with-resources
        // declarations and initializations: br and pw
       try( BufferedReader br = new BufferedReader(
               new InputStreamReader(
                  new FileInputStream("pokus.txt"), 
                     Charset.forName("UTF-8")));
            PrintWriter pw = new PrintWriter("pokus-out.txt", "UTF-8")) {
           
            String line = br.readLine();
            
            while(line != null) {
                pw.println(line);
                line = br.readLine();
            }
       }
    }
}
